# Identity Sequence Mixer

::: linax.sequence_mixers.identity.IdentitySequenceMixerConfig
    options:
      members:
        - build

---

::: linax.sequence_mixers.identity.IdentitySequenceMixer
    options:
      members:
        - __init__
        - __call__
